@@ -1,6 +1,7 @@
 from typing import Optional
 
 from fastapi import APIRouter, Depends
+from fastapi.exceptions import HTTPException
 
 from streams_explorer.api.dependencies.streams_explorer import (
     get_streams_explorer_from_request,
@@ -17,5 +18,12 @@ async def graph_positioned(
     streams_explorer: StreamsExplorer = Depends(get_streams_explorer_from_request),
 ):
     if pipeline_name:
-        return streams_explorer.get_positioned_pipeline_json_graph(pipeline_name)
+        pipeline_graph = await streams_explorer.get_positioned_pipeline_json_graph(
+            pipeline_name
+        )
+        if pipeline_graph is None:
+            raise HTTPException(
+                status_code=404, detail=f"Pipeline '{pipeline_name}' not found"
+            )
+        return pipeline_graph
     return streams_explorer.get_positioned_json_graph()
