@@ -1,9 +1,10 @@
+import asyncio
 from enum import Enum
-from typing import Dict, List, Optional
+from typing import Callable, Dict, List, Optional
 
+import httpx
 from loguru import logger
 from networkx.classes.reportviews import NodeDataView
-from prometheus_api_client import PrometheusApiClientException, PrometheusConnect
 
 from streams_explorer.core.config import settings
 from streams_explorer.models.graph import Metric
@@ -11,39 +12,64 @@ from streams_explorer.models.node_types import NodeTypesEnum
 
 
 class PrometheusMetric(Enum):
-    def __init__(self, metric: str, query: str):
+    def __init__(self, metric: str, query: str, key: str, value_transformer: Callable):
         self.metric: str = metric
         self.query: str = query
+        self._k: str = key
+        self._v: Callable = value_transformer
 
     MESSAGES_IN = (
         "messages_in",
         "sum by(topic) (rate(kafka_topic_partition_current_offset[5m]))",
+        "topic",
+        lambda d: round(float(d), 2),
     )
     MESSAGES_OUT = (
         "messages_out",
         "sum by(topic) (rate(kafka_consumergroup_group_offset[5m]) >= 0)",
+        "topic",
+        lambda d: round(float(d), 2),
     )
     CONSUMER_LAG = (
         "consumer_lag",
         'sum by(group) (kafka_consumergroup_group_topic_sum_lag{group=~".+"})',
+        "group",
+        int,
     )
     CONSUMER_READ_RATE = (
         "consumer_read_rate",
         'sum by(group) (rate(kafka_consumergroup_group_offset{group=~".+"}[5m]) >= 0)',
+        "group",
+        float,
     )
     TOPIC_SIZE = (
         "topic_size",
         "sum by(topic) (kafka_topic_partition_current_offset - kafka_topic_partition_oldest_offset)",
+        "topic",
+        float,
     )
     REPLICAS = (
         "replicas",
         "sum by(deployment) (kube_deployment_status_replicas)",
+        "deployment",
+        int,
+    )
+    REPLICAS_AVAILABLE = (
+        "replicas_available",
+        "sum by(deployment) (kube_deployment_status_replicas_available)",
+        "deployment",
+        int,
     )
     CONNECTOR_TASKS = (
         "connector_tasks",
         "sum by(connector) (kafka_connect_connector_tasks_state == 1) or clamp_max(sum by(connector) (kafka_connect_connector_tasks_state), 0)",
+        "connector",
+        int,
     )
 
+    def transform(self, data: list) -> dict:
+        return {d["metric"][self._k]: self._v(d["value"][-1]) for d in data}
+
 
 class MetricProvider:
     def __init__(self, nodes: NodeDataView):
@@ -51,7 +77,7 @@ class MetricProvider:
         self.metrics: List[Metric] = []
         self._data: Dict[str, dict] = {}
 
-    def refresh_data(self):
+    async def refresh_data(self):
         pass
 
     @staticmethod
@@ -61,8 +87,8 @@ class MetricProvider:
             return f"connect-{node_id}"
         return node.get(settings.k8s.consumer_group_annotation)
 
-    def update(self):
-        self.refresh_data()
+    async def update(self):
+        await self.refresh_data()
         self.metrics = [
             Metric(
                 node_id=node_id,
@@ -76,78 +102,50 @@ class MetricProvider:
                 messages_out=self._data["messages_out"].get(node_id),
                 topic_size=self._data["topic_size"].get(node_id),
                 replicas=self._data["replicas"].get(node_id),
+                replicas_available=self._data["replicas_available"].get(node_id),
                 connector_tasks=self._data["connector_tasks"].get(node_id),
             )
-            for node_id, node in self._nodes
+            for node_id, node in iter(self._nodes)
             if node_id
         ]
 
-    def get(self) -> List[Metric]:
-        self.update()
+    async def get(self) -> List[Metric]:
+        await self.update()
         return self.metrics
 
 
+class PrometheusException(Exception):
+    pass
+
+
 class PrometheusMetricProvider(MetricProvider):
     def __init__(self, nodes: NodeDataView):
         super().__init__(nodes)
-        self._prom = PrometheusConnect(url=settings.prometheus.url)
+        self._client = httpx.AsyncClient()
+        self._api_base = f"{settings.prometheus.url}/api/v1"
 
-    def get_metric(self, metric: PrometheusMetric) -> List:
+    async def _pull_metric(self, metric: PrometheusMetric) -> list:
         try:
-            return self.__prom_request(metric.query)
-        except PrometheusApiClientException as e:
+            return await self._query(metric.query)
+        except PrometheusException as e:
             logger.error(f"Error pulling {metric}: {e}")
         return []
 
-    def __prom_request(self, query: str) -> List:
-        return self._prom.custom_query(query)
+    async def _query(self, query: str) -> list:
+        r = await self._client.get(f"{self._api_base}/query", params={"query": query})
+        if r.status_code == httpx.codes.OK:
+            data = r.json()
+            if data and "data" in data and "result" in data["data"]:
+                return data["data"]["result"]
+        raise PrometheusException
 
-    def refresh_data(self):
+    async def refresh_data(self):
         logger.debug("Pulling metrics from Prometheus")
-        self._data["messages_in"] = self.__get_messages_in()
-        self._data["messages_out"] = self.__get_messages_out()
-        self._data["consumer_lag"] = self.__get_consumer_lag()
-        self._data["consumer_read_rate"] = self.__get_consumer_read_rate()
-        self._data["topic_size"] = self.__get_topic_size()
-        self._data["replicas"] = self.__get_replicas()
-        self._data["connector_tasks"] = self.__get_connector_tasks()
+        tasks = []
+        for metric in PrometheusMetric:
+            tasks.append(asyncio.ensure_future(self._process_metric(metric)))
+        await asyncio.gather(*tasks)
 
-    def __get_messages_in(self) -> Dict[str, float]:
-        prom_messages_in = self.get_metric(metric=PrometheusMetric.MESSAGES_IN)
-        return {
-            d["metric"]["topic"]: round(float(d["value"][-1]), 2)
-            for d in prom_messages_in
-        }
-
-    def __get_messages_out(self) -> Dict[str, float]:
-        prom_messages_out = self.get_metric(metric=PrometheusMetric.MESSAGES_OUT)
-        return {
-            d["metric"]["topic"]: round(float(d["value"][-1]), 2)
-            for d in prom_messages_out
-        }
-
-    def __get_consumer_lag(self) -> Dict[str, int]:
-        prom_consumer_lag = self.get_metric(metric=PrometheusMetric.CONSUMER_LAG)
-        return {d["metric"]["group"]: int(d["value"][-1]) for d in prom_consumer_lag}
-
-    def __get_consumer_read_rate(self) -> Dict[str, float]:
-        prom_consumer_read_rate = self.get_metric(
-            metric=PrometheusMetric.CONSUMER_READ_RATE
-        )
-        return {
-            d["metric"]["group"]: float(d["value"][-1]) for d in prom_consumer_read_rate
-        }
-
-    def __get_topic_size(self) -> Dict[str, int]:
-        prom_topic_size = self.get_metric(metric=PrometheusMetric.TOPIC_SIZE)
-        return {d["metric"]["topic"]: int(d["value"][-1]) for d in prom_topic_size}
-
-    def __get_replicas(self) -> Dict[str, int]:
-        prom_replicas = self.get_metric(metric=PrometheusMetric.REPLICAS)
-        return {d["metric"]["deployment"]: int(d["value"][-1]) for d in prom_replicas}
-
-    def __get_connector_tasks(self) -> Dict[str, int]:
-        prom_connector_tasks = self.get_metric(metric=PrometheusMetric.CONNECTOR_TASKS)
-        return {
-            d["metric"]["connector"]: int(d["value"][-1]) for d in prom_connector_tasks
-        }
+    async def _process_metric(self, metric: PrometheusMetric):
+        data = await self._pull_metric(metric)
+        self._data[metric.metric] = metric.transform(data)
